@@ -40,17 +40,17 @@ class Storage(driver.Base):
         object_instance = self._jss.bucket(self._bucket).object(path1)
         
         return object_instance.generate_url("GET")
-    
-    def get_json(self, path):
-        logger.info("get_json path:%s" % path)
-        try:
-            result = json.loads(self.get_unicode(path))
-            logger.info("get_json result:%s" % result)
-            return result
-        except Exception as e:
-            logger.error("get_json error:%s" % e)
-            return []
-        
+#    
+#    def get_json(self, path):
+#        logger.info("get_json path:%s" % path)
+#        try:
+#            result = json.loads(self.get_unicode(path))
+#            logger.info("get_json result:%s" % result)
+#            return result
+#        except Exception as e:
+#            logger.error("get_json error:%s" % e)
+#            return []
+#        
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
